==> yos.core-1.0.0-sources.jar: restcontroller/sysmanage/develop/userauthforweb/SQL/获取角色应用授权.sql <==
select distinct t.systemmoduleid, t.systemappid, t.systemapp, t.systemappname, t.apppath, t.sequence,t.isdatatag,t.isdatateam,t.isdatafollowup,t.selectfileinattachment
from (
         select distinct t4.systemmoduleid, t3.systemappid, t3.systemapp, t3.systemappname, t3.apppath, t3.sequence,t3.isdatatag,t3.isdatateam,t3.isdatafollowup,t3.selectfileinattachment
         from sys_roleappoptionauth t1
                  inner join sys_systemapp_options t2 on t1.optionid = t2.optionid and t2.isused = 1
                  inner join sys_systemapp t3 on t2.systemappid = t3.systemappid and t3.isused = 1 and (t3.showplace = $showplace$ or $showplace$ = '1')
                  inner join sys_systemmodule t4 on t3.systemmoduleid = t4.systemmoduleid and t4.isused = 1
                  inner join sys_systemclient t5 on t4.systemclientid = t5.systemclientid and t5.isused = 1
         where t5.systemclient = $systemclient$
           and exists(select * from sys_userrole where roleid = t1.roleid and userid = $userid$ and siteid = $siteid$)
         union all
         select distinct t1.systemmoduleid, t1.systemappid, t1.systemapp, t1.systemappname, t1.apppath, t1.sequence,t1.isdatatag,t1.isdatateam,t1.isdatafollowup,t1.selectfileinattachment
         from sys_systemapp t1
                  inner join sys_systemmodule t2 on t1.systemmoduleid = t2.systemmoduleid and t2.isused = 1
                  inner join sys_systemclient t3 on t2.systemclientid = t3.systemclientid and t3.isused = 1
         where t1.isused = 1
           and t1.isneedauth = 0
           and t3.systemclient = $systemclient$ and  (t1.showplace = $showplace$ or $showplace$ = '1')) t
order by t.sequence

==> yos.core-2.0.1-sources.jar: restcontroller/sysmanage/develop/userauthforweb/SQL/获取角色应用授权.sql <==
select distinct t.systemmoduleid, t.systemappid, t.systemapp, t.systemappname, t.apppath,t.apppath_index, t.sequence,t.isdatatag,t.isdatateam,t.isdatafollowup,t.selectfileinattachment
from (
         select distinct t4.systemmoduleid, t3.systemappid, t3.systemapp, t3.systemappname, t3.apppath,t3.apppath_index, t3.sequence,t3.isdatatag,t3.isdatateam,t3.isdatafollowup,t3.selectfileinattachment
         from sys_roleappoptionauth t1
                  inner join sys_systemapp_options t2 on t1.optionid = t2.optionid and t2.isused = 1
                  inner join sys_systemapp t3 on t2.systemappid = t3.systemappid and t3.isused = 1 and (t3.showplace = $showplace$ or $showplace$ = '1')
                  inner join sys_systemmodule t4 on t3.systemmoduleid = t4.systemmoduleid and t4.isused = 1
                  inner join sys_systemclient t5 on t4.systemclientid = t5.systemclientid and t5.isused = 1
         where t5.systemclient = $systemclient$
           and exists(select * from sys_userrole where roleid = t1.roleid and userid = $userid$ and siteid = $siteid$)
         union all
         select distinct t1.systemmoduleid, t1.systemappid, t1.systemapp, t1.systemappname, t1.apppath,t1.apppath_index, t1.sequence,t1.isdatatag,t1.isdatateam,t1.isdatafollowup,t1.selectfileinattachment
         from sys_systemapp t1
                  inner join sys_systemmodule t2 on t1.systemmoduleid = t2.systemmoduleid and t2.isused = 1
                  inner join sys_systemclient t3 on t2.systemclientid = t3.systemclientid and t3.isused = 1
         where t1.isused = 1
           and t1.isneedauth = 0
           and t3.systemclient = $systemclient$ and  (t1.showplace = $showplace$ or $showplace$ = '1')) t
order by t.sequence
